from dataclasses import dataclass

        
@dataclass
class RenderConfig:
    """
    The configuration of the rendering process,
    which includes the quality, the fps, the size,
    etc.
    """

    def __init__(
        self,
        size:  tuple[int, int],
        fps: float,
        do_use_gpu: bool
    ):
        self.size: tuple[int, int] = size
        """
        The size that will be used for the output of the
        rendering process.
        """
        self.fps: float = fps
        """
        The fps for the output of the rendering process.
        """
        self.do_use_gpu: bool = do_use_gpu
        """
        Flag to indicate if processing the rendering with
        GPU (if `True`) or with CPU (if `False`).
        """